@@ -23,9 +23,9 @@ ceilosca_files = {
     for file in
     [
         'monasca_client.py',
-        'monasca_ceilometer_opts.py',
+        'monasca_opts.py',
         'publisher/monasca_data_filter.py',
-        'publisher/monclient.py'
+        'publisher/monasca.py'
     ]
 }
 
@@ -34,11 +34,6 @@ ceilosca_files = {
 for src, dest in ceilosca_files.items():
     shutil.copyfile(src, dest)
 
-# Include new module
-shutil.rmtree(ceilo_dir + "/ceilosca_mapping/", True)
-shutil.copytree('ceilosca/ceilometer/ceilosca_mapping',
-                ceilo_dir + "/ceilosca_mapping/")
-
 ceilo_parent_dir = os.path.dirname(os.path.abspath(
     os.path.dirname(ceilometer.__file__)))
 
